var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Inject, Injector, Optional, NgZone, ElementRef, forwardRef, NgModule, ViewEncapsulation } from '@angular/core';
import { EventEmitter } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/mergeAll';
import { OntimizeService, DialogService, OFormComponent, InputConverter, Util, ObservableWrapper, OSharedModule } from 'ontimize-web-ng2';
import { OLightTableButtonPanelModule } from './o-light-table-button-panel.component';
import { OLightTableColumnModule } from './o-light-table-column.component';
import { CommonModule } from '@angular/common';
export var DEFAULT_INPUTS_O_LIGHT_TABLE = [
    'refreshButton: refresh-button',
    'queryOnInit: query-on-init',
    'columns',
    'parentKeys: parent-keys',
    'entity',
    'service',
    'key',
    'route',
    'staticData: static-data'
];
export var DEFAULT_OUTPUTS_O_LIGHT_TABLE = [
    'onRowClick'
];
var OLightTableComponent = (function () {
    function OLightTableComponent(router, actRoute, el, zone, injector, form) {
        this.queryOnInit = true;
        this.refreshButton = true;
        this.showControls = true;
        this.markAll = false;
        this.selected = [];
        this.deleting = false;
        this.dataArray = [];
        this.serviceData = [];
        this.colArray = [];
        this.oColumns = {};
        this.onRowClick = new EventEmitter();
        this._pKeysEquiv = {};
        this._router = router;
        this._actRoute = actRoute;
        this.elRef = el;
        this._injector = injector;
        this._dialogService = injector.get(DialogService);
    }
    OLightTableComponent.prototype.registerColumn = function (col) {
        if (col) {
            this.oColumns[col.id] = col;
            this.colArray.push(col.id);
        }
    };
    OLightTableComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.colArray = Util.parseArray(this.columns);
        var pkArray = Util.parseArray(this.parentKeys);
        if (pkArray && pkArray.length > 0) {
            pkArray.forEach(function (item) {
                var aux = item.split(':');
                if (aux && aux.length === 2) {
                    _this._pKeysEquiv[aux[0]] = aux[1];
                }
                else if (aux && aux.length === 1) {
                    _this._pKeysEquiv[item] = item;
                }
            });
        }
        if (this.staticData) {
            this.dataArray = this.staticData;
        }
        else {
            this.configureService();
        }
    };
    OLightTableComponent.prototype.configureService = function () {
        this.dataService = this._injector.get(OntimizeService);
        if (Util.isDataService(this.dataService)) {
            var serviceCfg = this.dataService.getDefaultServiceConfiguration(this.service);
            if (this.entity) {
                serviceCfg['entity'] = this.entity;
            }
            this.dataService.configureService(serviceCfg);
        }
    };
    OLightTableComponent.prototype.ngAfterViewInit = function () {
        if (this.queryOnInit) {
            this.queryData();
        }
    };
    OLightTableComponent.prototype.setData = function (data) {
        this.dataArray = data;
    };
    OLightTableComponent.prototype.renderColumn = function (rowIdx, colIdx, col, value, wrapperEL) {
        var oColumn = this.oColumns[col];
        if (oColumn) {
            return oColumn.getRenderedValue(value);
        }
        return value;
    };
    OLightTableComponent.prototype.getPipe = function (col) {
        var oColum = this.oColumns[col];
        return oColum.pipe ? oColum.pipe : '';
    };
    OLightTableComponent.prototype.getFlex = function (col) {
        var oColum = this.oColumns[col];
        return oColum.flex ? oColum.flex : 'auto';
    };
    OLightTableComponent.prototype.queryData = function (filter) {
        if (filter === void 0) { filter = {}; }
        var self = this;
        this.dataService.query(filter, [], this.entity)
            .subscribe(function (resp) {
            if (resp.code === 0) {
                self.setData(resp.data);
                self.serviceData = resp.data;
            }
            else {
                console.log('error');
            }
        }, function (err) {
            console.log(err);
        });
    };
    OLightTableComponent.prototype.handleMarkAll = function (event, selected) {
        if (this.dataArray && this.dataArray.length > 0) {
            for (var i = 0; i < this.dataArray.length; ++i) {
                var idx = this.selected.indexOf(this.dataArray[i]);
                if (!selected && idx < 0) {
                    this.selected.push(this.dataArray[i]);
                }
                else if (selected && idx > -1) {
                    this.selected.splice(idx, 1);
                }
            }
        }
    };
    OLightTableComponent.prototype.syncSelected = function (item) {
        var idx = this.selected.indexOf(item);
        if (idx > -1) {
            this.selected.splice(idx, 1);
        }
        else {
            this.selected.push(item);
        }
    };
    OLightTableComponent.prototype.isItemSelected = function (item) {
        return this.selected.indexOf(item) > -1;
    };
    OLightTableComponent.prototype.onListItemClick = function (item, event) {
        if (!this.deleting) {
            if (this.route && this.route.length > 0) {
                var params = {};
                params[this.key] = item[this.key];
                params['isdetail'] = true;
                this._router.navigate(['/' + this.route, params]);
            }
        }
        else {
            this.syncSelected(item);
            if (this.markAll) {
                this.markAll = false;
            }
        }
        ObservableWrapper.callEmit(this.onRowClick, item);
    };
    OLightTableComponent.prototype.onRowClicked = function (onNext) {
        return ObservableWrapper.subscribe(this.onRowClick, onNext);
    };
    OLightTableComponent.prototype.cancelRemove = function (event) {
        this.selected = [];
        this.markAll = false;
        this.deleting = false;
    };
    OLightTableComponent.prototype.filter = function (event) {
    };
    OLightTableComponent.prototype.remove = function (event) {
        if (this.deleting) {
            this.showConfirmDelete(event);
        }
        else {
            this.deleting = true;
        }
    };
    OLightTableComponent.prototype.add = function (event) {
        var params = {};
        this._router.navigate(['/New' + this.route, params]);
    };
    OLightTableComponent.prototype.showConfirmDelete = function (evt) {
        var _this = this;
        this._dialogService.confirm('CONFIRM', 'MESSAGES.CONFIRM_DELETE')
            .then(function (res) {
            if (res === true) {
                _this.executeMassiveRemove();
            }
        });
    };
    OLightTableComponent.prototype.executeMassiveRemove = function () {
        var _this = this;
        if (this.selected && this.selected.length > 0) {
            var massiveFilters_1 = [];
            this.selected.map(function (item) {
                var filter = {};
                filter[_this.key] = item[_this.key];
                massiveFilters_1.push(filter);
            });
            this.removeRegister(massiveFilters_1);
        }
    };
    OLightTableComponent.prototype.removeRegister = function (filter) {
        var _this = this;
        var obs = Observable.fromArray(filter)
            .map(function (item) { return _this.dataService.delete(item, _this.entity); }).mergeAll();
        obs.subscribe(function (resp) {
            console.log();
        }, function (error) {
            _this._dialogService.alert('ERROR', 'MESSAGES.ERROR_DELETE');
        }, function () {
            _this._dialogService.alert('INFO', 'MESSAGES.SUCCESS_DELETE')
                .then(function (res) {
                _this.deleting = false;
                _this.queryData();
            });
        });
    };
    OLightTableComponent.DEFAULT_INPUTS_O_LIGHT_TABLE = DEFAULT_INPUTS_O_LIGHT_TABLE;
    OLightTableComponent.DEFAULT_OUTPUTS_O_LIGHT_TABLE = DEFAULT_OUTPUTS_O_LIGHT_TABLE;
    OLightTableComponent.decorators = [
        { type: Component, args: [{
                    selector: 'o-light-table',
                    template: "\n    <ng-content *ngIf=\"false\"></ng-content>\n    <div fxFill class=\"container\">\n      <o-light-table-button-panel *ngIf=\"showControls\"></o-light-table-button-panel>\n      <md-toolbar class=\"o-light-table-header\">\n        <div class=\"mat-toolbar-tools\">\n          <md-checkbox [(checked)]=\"markAll\" (click)=\"handleMarkAll($event, markAll)\" aria-label=\"Mark all to delete\" *ngIf=\"deleting\"></md-checkbox>\n          <div *ngFor=\"let col of colArray\" class=\"clip-text\" fxFlex=\"auto\"> {{ oColumns[col].title }} </div>\n        </div>\n      </md-toolbar>\n      <md-list>\n        <md-list-item *ngFor=\"let item of dataArray; let rowIndex = index\" (click)=\"onListItemClick(item, $event)\">\n          <div id=\"row_{{rowIndex}}\" class=\"mat-no-style mat-list-item-inner\">\n            <md-checkbox [checked]=\"isItemSelected(item)\"  aria-label=\"Mark to delete\" *ngIf=\"deleting\"></md-checkbox>\n            <div fxLayout=\"row\" fxFill>\n              <div #colWrapper *ngFor=\"let col of colArray; let colIndex = index\" id=\"col_{{rowIndex}}_{{colIndex}}\"\n                class=\"clip-text\" fxFlex=\"auto\">\n                  {{ renderColumn(rowIndex, colIndex, col, item[col], colWrapper) }}\n              </div>\n            </div>\n            <span><i class=\"material-icons\" >navigate_next</i></span>\n          </div>\n          <md-divider></md-divider>\n        </md-list-item>\n      </md-list>\n     </div>\n  ",
                    styles: ["\n    .container{overflow-y:hidden}md-toolbar.o-light-table-header{background-color:#eee;color:rgba(0,0,0,0.87);border-top:1px solid #fff;border-bottom:1px solid #fff;padding:0px 40px 0px 0px;height:48px;min-height:48px}@media (max-width: 600px) and (min-width: 0) and (orientation: portrait){md-toolbar.o-light-table-header{top:112px}}@media (max-width: 600px) and (min-width: 0) and (orientation: landscape){md-toolbar.o-light-table-header{top:96px}}md-toolbar.o-light-table-header.no-padding{padding:0px}md-toolbar.o-light-table-header md-checkbox{width:50px;height:18px;margin-left:3px;padding:0px 12px 0px 60px}md-toolbar.o-light-table-header div{font-weight:bold;font-size:16px}md-list{overflow-y:auto;height:calc(100% - (48px + 16px));height:-moz-calc(100% - (48px + 16px));height:-webkit-calc(100% - (48px + 16px))}md-list md-list-item{cursor:pointer}md-list md-list-item md-checkbox[disabled]{cursor:pointer}md-list md-list-item md-icon{margin-left:15px;font-size:30px}\n  "],
                    providers: [OntimizeService],
                    inputs: DEFAULT_INPUTS_O_LIGHT_TABLE.slice(),
                    outputs: DEFAULT_OUTPUTS_O_LIGHT_TABLE.slice(),
                    encapsulation: ViewEncapsulation.None
                },] },
    ];
    OLightTableComponent.ctorParameters = function () { return [
        { type: Router, },
        { type: ActivatedRoute, },
        { type: ElementRef, },
        { type: NgZone, },
        { type: Injector, },
        { type: OFormComponent, decorators: [{ type: Optional }, { type: Inject, args: [forwardRef(function () { return OFormComponent; }),] },] },
    ]; };
    __decorate([
        InputConverter(),
        __metadata("design:type", Boolean)
    ], OLightTableComponent.prototype, "queryOnInit", void 0);
    __decorate([
        InputConverter(),
        __metadata("design:type", Boolean)
    ], OLightTableComponent.prototype, "refreshButton", void 0);
    __decorate([
        InputConverter(),
        __metadata("design:type", Boolean)
    ], OLightTableComponent.prototype, "showControls", void 0);
    return OLightTableComponent;
}());
export { OLightTableComponent };
var OLightTableModule = (function () {
    function OLightTableModule() {
    }
    OLightTableModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [OLightTableComponent],
                    imports: [OSharedModule, CommonModule, OLightTableColumnModule, OLightTableButtonPanelModule],
                    exports: [OLightTableComponent],
                },] },
    ];
    OLightTableModule.ctorParameters = function () { return []; };
    return OLightTableModule;
}());
export { OLightTableModule };
//# sourceMappingURL=o-light-table.component.js.map