import { Component, Inject, forwardRef, EventEmitter } from '@angular/core';
import { ObservableWrapper } from 'ontimize-web-ng2';
import { ODataTableColumnComponent } from '../o-datatable-column.component';
var ODataTableCellEditorBooleanComponent = (function () {
    function ODataTableCellEditorBooleanComponent(tableColumn) {
        this.onFocus = new EventEmitter();
        this.onBlur = new EventEmitter();
        this.onSubmit = new EventEmitter();
        this.tableColumn = tableColumn;
        this.tableColumn.registerEditor(this);
    }
    ODataTableCellEditorBooleanComponent.prototype.init = function (parameters) {
    };
    ODataTableCellEditorBooleanComponent.prototype.getHtml = function (data) {
        var html = '<input type="checkbox" ';
        if (data === true) {
            html += 'checked ';
        }
        html += 'onclick="event.stopPropagation();" ondblclick="event.stopPropagation();" />';
        return html;
    };
    ODataTableCellEditorBooleanComponent.prototype.handleCellFocus = function (cellElement, data) {
        this.create(cellElement, data);
    };
    ODataTableCellEditorBooleanComponent.prototype.handleCellBlur = function (cellElement) {
        this.performInsertion(cellElement);
    };
    ODataTableCellEditorBooleanComponent.prototype.create = function (cellElement, data) {
        var _this = this;
        var input = cellElement.find('input');
        if (input.length === 0) {
            cellElement.addClass('editing');
            cellElement.html(this.getHtml(data));
            input = cellElement.find('input');
            input.width(input.width() - 24);
            input.bind('keypress', function (e) {
                var code = e.keyCode || e.which;
                if (code === 13) {
                    ObservableWrapper.callEmit(_this.onSubmit, { editor: _this });
                    _this.performInsertion(cellElement);
                }
            });
            input.bind('focus', function (e) {
                ObservableWrapper.callEmit(_this.onFocus, { editor: _this });
            });
            input.bind('focusout', function (e) {
                ObservableWrapper.callEmit(_this.onBlur, { editor: _this });
                _this.performInsertion(cellElement);
            });
            input.focus();
            input.select();
        }
    };
    ODataTableCellEditorBooleanComponent.prototype.destroy = function (cellElement) {
        var input = cellElement.find('input');
        if (input.length > 0) {
            cellElement.removeClass('editing');
            input.remove();
        }
    };
    ODataTableCellEditorBooleanComponent.prototype.performInsertion = function (cellElement) {
        var input = cellElement.find('input');
        if (input.length > 0) {
            var newValue = input.prop('checked');
            this.destroy(cellElement);
            this.tableColumn.updateCell(cellElement, newValue);
        }
    };
    ODataTableCellEditorBooleanComponent.prototype.createEditorForInsertTable = function (cellElement, data) {
        var _this = this;
        cellElement.html(this.getHtml(data));
        this.insertTableInput = cellElement.find('input');
        this.insertTableInput.bind('keydown', function (e) {
            var code = e.keyCode || e.which;
            if (code === 13) {
                ObservableWrapper.callEmit(_this.onSubmit, { insertTable: true, editor: _this });
            }
        });
        this.insertTableInput.bind('focus', function (e) {
            ObservableWrapper.callEmit(_this.onFocus, { insertTable: true, editor: _this });
        });
        this.insertTableInput.bind('focusout', function (e) {
            ObservableWrapper.callEmit(_this.onBlur, { insertTable: true, editor: _this });
        });
    };
    ODataTableCellEditorBooleanComponent.prototype.getInsertTableValue = function () {
        var value = undefined;
        if (typeof (this.insertTableInput) !== 'undefined') {
            value = this.insertTableInput.prop('checked');
        }
        return value;
    };
    ODataTableCellEditorBooleanComponent.decorators = [
        { type: Component, args: [{
                    selector: 'o-datatable-cell-editor-boolean',
                    template: '',
                    outputs: [
                        'onFocus',
                        'onBlur',
                        'onSubmit'
                    ]
                },] },
    ];
    ODataTableCellEditorBooleanComponent.ctorParameters = function () { return [
        { type: ODataTableColumnComponent, decorators: [{ type: Inject, args: [forwardRef(function () { return ODataTableColumnComponent; }),] },] },
    ]; };
    return ODataTableCellEditorBooleanComponent;
}());
export { ODataTableCellEditorBooleanComponent };
//# sourceMappingURL=o-datatable-cell-editor-boolean.component.js.map