import * as $ from 'jquery';
import { Component, Inject, Injector, forwardRef, EventEmitter } from '@angular/core';
import { ObservableWrapper, OntimizeService, dataServiceFactory, Util } from 'ontimize-web-ng2';
import { ODataTableColumnComponent } from '../o-datatable-column.component';
import { ODataTableComponent } from '../o-datatable.component';
export var DEFAULT_INPUTS_O_TABLE_CELL_EDITOR_COMBO = [
    'service',
    'queryMethod: query-method',
    'entity',
    'valueColumn: value-column',
    'columns',
    'visibleColumns: visible-columns',
    'separator'
];
var ODataTableCellEditorComboComponent = (function () {
    function ODataTableCellEditorComboComponent(tableColumn, injector) {
        this.injector = injector;
        this.onFocus = new EventEmitter();
        this.onBlur = new EventEmitter();
        this.onSubmit = new EventEmitter();
        this.tableColumn = tableColumn;
        this.tableColumn.registerEditor(this);
        this.componentData = {};
        this.dataType = 'undefined';
    }
    ODataTableCellEditorComboComponent.prototype.ngOnInit = function () {
        if (typeof (this.separator) === 'undefined') {
            this.separator = '';
        }
        if (typeof (this.queryMethod) === 'undefined') {
            this.queryMethod = 'query';
        }
        this.init(undefined);
    };
    ODataTableCellEditorComboComponent.prototype.init = function (parameters) {
        if (typeof (parameters) !== 'undefined') {
            if (typeof (parameters.service) !== 'undefined') {
                this.service = parameters.service;
            }
            if (typeof (parameters.entity) !== 'undefined') {
                this.entity = parameters.entity;
            }
            if (typeof (parameters.valueColumn) !== 'undefined') {
                this.valueColumn = parameters.valueColumn;
            }
            if (typeof (parameters.columns) !== 'undefined') {
                this.columns = parameters.columns;
            }
            if (typeof (parameters.visibleColumns) !== 'undefined') {
                this.visibleColumns = parameters.visibleColumns;
            }
            if (typeof (parameters.separator) !== 'undefined') {
                this.separator = parameters.separator;
            }
            if (typeof (parameters.queryMethod) !== 'undefined') {
                this.queryMethod = parameters.queryMethod;
            }
        }
        if (this.columns) {
            this.dataColumns = this.columns.split(ODataTableComponent.COLUMNS_SEPARATOR);
        }
        else {
            this.dataColumns = [];
        }
        if (this.visibleColumns) {
            this.dataVisibleColumns = this.visibleColumns.split(ODataTableComponent.COLUMNS_SEPARATOR);
        }
        else {
            this.dataVisibleColumns = [];
        }
        this.configureService();
        this.queryData();
    };
    ODataTableCellEditorComboComponent.prototype.configureService = function () {
        this.dataService = this.injector.get(OntimizeService);
        if (Util.isDataService(this.dataService)) {
            var serviceCfg = this.dataService.getDefaultServiceConfiguration(this.service);
            if (this.entity) {
                serviceCfg['entity'] = this.entity;
            }
            this.dataService.configureService(serviceCfg);
        }
    };
    ODataTableCellEditorComboComponent.prototype.getHtml = function (data) {
        var html = '<select onclick="event.stopPropagation();" ondblclick="event.stopPropagation();">';
        html += '<option value="null"></option>';
        for (var i in this.componentData) {
            html += '<option value="' + i + '">' + String(this.componentData[i]) + '</option>';
        }
        html += '</select>';
        return html;
    };
    ODataTableCellEditorComboComponent.prototype.handleCellFocus = function (cellElement, data) {
        this.create(cellElement, data);
    };
    ODataTableCellEditorComboComponent.prototype.handleCellBlur = function (cellElement) {
        this.performInsertion(cellElement);
    };
    ODataTableCellEditorComboComponent.prototype.create = function (cellElement, data) {
        var _this = this;
        var input = cellElement.find('select');
        if (input.length === 0) {
            cellElement.addClass('editing');
            cellElement.html(this.getHtml(data));
            input = cellElement.find('select');
            if (typeof (data) !== 'undefined') {
                this.dataType = typeof (data);
                input.val(data);
            }
            input.bind('change', function (e) {
                ObservableWrapper.callEmit(_this.onSubmit, { editor: _this });
                _this.performInsertion(cellElement);
            });
            input.bind('focus', function (e) {
                ObservableWrapper.callEmit(_this.onFocus, { editor: _this });
            });
            input.bind('focusout', function (e) {
                ObservableWrapper.callEmit(_this.onBlur, { editor: _this });
                _this.performInsertion(cellElement);
            });
            input.focus();
        }
    };
    ODataTableCellEditorComboComponent.prototype.destroy = function (cellElement) {
        var input = cellElement.find('select');
        if (input.length > 0) {
            cellElement.removeClass('editing');
            input.remove();
        }
    };
    ODataTableCellEditorComboComponent.prototype.performInsertion = function (cellElement) {
        var input = cellElement.find('select');
        if (input.length > 0) {
            var newValue = input.val();
            if (newValue === 'null') {
                newValue = null;
            }
            else {
                switch (this.dataType) {
                    case 'number':
                        newValue = parseInt(newValue);
                        break;
                }
            }
            this.destroy(cellElement);
            this.tableColumn.updateCell(cellElement, newValue);
        }
    };
    ODataTableCellEditorComboComponent.prototype.createEditorForInsertTable = function (cellElement, data) {
        var _this = this;
        cellElement.html(this.getHtml(data));
        this.insertTableInput = cellElement.find('select');
        if (typeof (data) !== 'undefined') {
            this.dataType = typeof (data);
            this.insertTableInput.val(data);
        }
        this.insertTableInput.bind('change', function (e) {
            ObservableWrapper.callEmit(_this.onSubmit, { insertTable: true, editor: _this });
        });
        this.insertTableInput.bind('focus', function (e) {
            ObservableWrapper.callEmit(_this.onFocus, { insertTable: true, editor: _this });
        });
        this.insertTableInput.bind('focusout', function (e) {
            ObservableWrapper.callEmit(_this.onBlur, { insertTable: true, editor: _this });
        });
    };
    ODataTableCellEditorComboComponent.prototype.getInsertTableValue = function () {
        var value = undefined;
        if (typeof (this.insertTableInput) !== 'undefined') {
            value = this.insertTableInput.val();
            if (value === 'null') {
                value = null;
            }
            else {
                switch (this.dataType) {
                    case 'number':
                        value = parseInt(value);
                        break;
                }
            }
        }
        return value;
    };
    ODataTableCellEditorComboComponent.prototype.queryData = function () {
        var _this = this;
        if (this.dataService && (this.queryMethod in this.dataService) && this.entity && this.valueColumn) {
            this.dataService[this.queryMethod]({}, this.dataColumns, this.entity).subscribe(function (res) {
                var data = undefined;
                if ($.isArray(res)) {
                    data = res;
                }
                else if ((res.code === 0) && $.isArray(res.data)) {
                    data = res.data;
                }
                if ($.isArray(data)) {
                    for (var i = 0; i < data.length; ++i) {
                        var item = data[i];
                        var key = item[_this.valueColumn];
                        if (typeof (key) !== 'undefined') {
                            var value = '';
                            for (var j = 0; j < _this.dataVisibleColumns.length; ++j) {
                                var col = _this.dataVisibleColumns[j];
                                if (typeof (item[col]) !== 'undefined') {
                                    if (j > 0) {
                                        value += _this.separator;
                                    }
                                    value += String(item[col]);
                                }
                            }
                            _this.componentData[key] = value;
                        }
                    }
                }
                else {
                    console.log('[ODataTableCellEditorComboComponent.init]: error code ' + res.code + ' when querying data');
                }
            }, function (err) {
                console.log('[ODataTableCellEditorComboComponent.init]: error', err);
            });
        }
    };
    ODataTableCellEditorComboComponent.DEFAULT_INPUTS_O_TABLE_CELL_EDITOR_COMBO = DEFAULT_INPUTS_O_TABLE_CELL_EDITOR_COMBO;
    ODataTableCellEditorComboComponent.decorators = [
        { type: Component, args: [{
                    selector: 'o-datatable-cell-editor-combo',
                    template: '',
                    providers: [
                        { provide: OntimizeService, useFactory: dataServiceFactory, deps: [Injector] }
                    ],
                    inputs: DEFAULT_INPUTS_O_TABLE_CELL_EDITOR_COMBO.slice(),
                    outputs: [
                        'onFocus',
                        'onBlur',
                        'onSubmit'
                    ]
                },] },
    ];
    ODataTableCellEditorComboComponent.ctorParameters = function () { return [
        { type: ODataTableColumnComponent, decorators: [{ type: Inject, args: [forwardRef(function () { return ODataTableColumnComponent; }),] },] },
        { type: Injector, },
    ]; };
    return ODataTableCellEditorComboComponent;
}());
export { ODataTableCellEditorComboComponent };
//# sourceMappingURL=o-datatable-cell-editor-combo.component.js.map