import { Component, Inject, Injector, forwardRef, EventEmitter } from '@angular/core';
import { MdDialog } from '@angular/material';
import { ObservableWrapper, SQLTypes, MomentService } from 'ontimize-web-ng2';
import * as moment from 'moment';
import { ODataTableColumnComponent } from '../o-datatable-column.component';
import { ODataTableCellEditorDateDialog } from './dialog/o-datatable-cell-editor-date-dialog.component';
export var DEFAULT_INPUTS_O_DATATABLE_CELL_EDITOR_DATE = [
    'dateModelType: date-model-type',
    'dateModelFormat: date-model-format'
];
var ODataTableCellEditorDateComponent = (function () {
    function ODataTableCellEditorDateComponent(tableColumn, injector) {
        this.tableColumn = tableColumn;
        this.injector = injector;
        this.onFocus = new EventEmitter();
        this.onBlur = new EventEmitter();
        this.onSubmit = new EventEmitter();
        this.tableColumn = tableColumn;
        this.momentService = this.injector.get(MomentService);
        this.ng2Dialog = this.injector.get(MdDialog);
        this.tableColumn.registerEditor(this);
        this.datePickerFormat = moment.localeData(this.momentService.getLocale())['_longDateFormat']['L'];
        this.datePickerFormat = this.datePickerFormat.toLowerCase().replace(/yyyy/g, 'yy');
        this.previousValue = undefined;
        this.rendererFormat = undefined;
    }
    ODataTableCellEditorDateComponent.prototype.ngOnInit = function () {
        if (typeof (this.dateModelType) === 'undefined') {
            this.dateModelType = ODataTableCellEditorDateComponent.DEFAULT_DATE_MODEL_TYPE;
        }
        if (typeof (this.dateModelFormat) === 'undefined') {
            this.dateModelFormat = ODataTableCellEditorDateComponent.DEFAULT_DATE_MODEL_FORMAT;
        }
    };
    ODataTableCellEditorDateComponent.prototype.init = function (parameters) {
        if (typeof (parameters) !== 'undefined') {
            if (typeof (parameters.dateModelType) !== 'undefined') {
                this.dateModelType = parameters.dateModelType;
            }
            if (typeof (parameters.dateModelFormat) !== 'undefined') {
                this.dateModelFormat = parameters.dateModelFormat;
            }
            if (typeof (parameters.rendererFormat) !== 'undefined') {
                this.rendererFormat = parameters.rendererFormat;
            }
        }
    };
    ODataTableCellEditorDateComponent.prototype.getHtml = function (data) {
        return '';
    };
    ODataTableCellEditorDateComponent.prototype.handleCellBlur = function (cellElement) {
    };
    ODataTableCellEditorDateComponent.prototype.create = function (cellElement, data) {
    };
    ODataTableCellEditorDateComponent.prototype.destroy = function (cellElement) {
    };
    ODataTableCellEditorDateComponent.prototype.performInsertion = function (newValue) {
        var timestampValue = undefined;
        if (newValue instanceof Date) {
            var dateTimestamp = newValue.getTime();
            if (dateTimestamp !== this.previousValue) {
                timestampValue = dateTimestamp;
            }
        }
        if (timestampValue !== undefined) {
            var sqlTypes = {};
            sqlTypes[this.tableColumn.attr] = SQLTypes.getSQLTypeValue('DATE');
            this.tableColumn.updateCell(this.cellElement, timestampValue, sqlTypes);
        }
    };
    ODataTableCellEditorDateComponent.prototype.handleCellFocus = function (cellElement, data) {
        this.configureAndOpenDialog(cellElement, data);
    };
    ODataTableCellEditorDateComponent.prototype.createEditorForInsertTable = function (cellElement, data) {
        this.configureAndOpenDialog(cellElement, data);
    };
    ODataTableCellEditorDateComponent.prototype.getInsertTableValue = function () {
        return undefined;
    };
    ODataTableCellEditorDateComponent.prototype.configureAndOpenDialog = function (cellElement, data) {
        this.cellElement = cellElement;
        this.previousValue = data;
        ObservableWrapper.callEmit(this.onFocus, { editor: this });
        this.openDialog(data);
    };
    ODataTableCellEditorDateComponent.prototype.openDialog = function (data) {
        var _this = this;
        var cfg = {
            role: 'dialog',
            disableClose: false,
            width: '300px',
            height: '280px'
        };
        this.dialogRef = this.ng2Dialog.open(ODataTableCellEditorDateDialog, cfg);
        this.dialogRef.afterClosed().subscribe(function (result) {
            _this.onDialogClose(result);
        });
        this.dialogRef.componentInstance.initialize({
            data: data,
            label: this.tableColumn.attr
        });
    };
    ODataTableCellEditorDateComponent.prototype.onDialogClose = function (value) {
        ObservableWrapper.callEmit(this.onBlur, { editor: this });
        if (value) {
            this.performInsertion(value);
        }
        ObservableWrapper.callEmit(this.onSubmit, { editor: this });
    };
    ODataTableCellEditorDateComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_EDITOR_DATE = DEFAULT_INPUTS_O_DATATABLE_CELL_EDITOR_DATE;
    ODataTableCellEditorDateComponent.DEFAULT_DATE_MODEL_TYPE = 'timestamp';
    ODataTableCellEditorDateComponent.DEFAULT_DATE_MODEL_FORMAT = 'YYYY-MM-DD HH:mm:ss';
    ODataTableCellEditorDateComponent.decorators = [
        { type: Component, args: [{
                    selector: 'o-datatable-cell-editor-date',
                    template: '',
                    inputs: DEFAULT_INPUTS_O_DATATABLE_CELL_EDITOR_DATE.slice(),
                    outputs: [
                        'onFocus',
                        'onBlur',
                        'onSubmit'
                    ]
                },] },
    ];
    ODataTableCellEditorDateComponent.ctorParameters = function () { return [
        { type: ODataTableColumnComponent, decorators: [{ type: Inject, args: [forwardRef(function () { return ODataTableColumnComponent; }),] },] },
        { type: Injector, },
    ]; };
    return ODataTableCellEditorDateComponent;
}());
export { ODataTableCellEditorDateComponent };
//# sourceMappingURL=o-datatable-cell-editor-date.component.js.map