import { Component, Inject, Injector, forwardRef, EventEmitter } from '@angular/core';
import { OTranslateService } from 'ontimize-web-ng2';
import { ODataTableColumnComponent } from '../o-datatable-column.component';
export var DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_ACTION = [
    'action',
    'editionMode : edition-mode',
    'renderType: render-type',
    'renderValue: render-value',
    'actionTitle : action-title'
];
export var DEFAULT_OUTPUTS_O_DATATABLE_CELL_RENDERER_ACTION = [
    'onClick'
];
var ODataTableCellRendererActionComponent = (function () {
    function ODataTableCellRendererActionComponent(tableColumn, injector) {
        this.injector = injector;
        this.onClick = new EventEmitter();
        this.tableColumn = tableColumn;
        this.tableColumn.registerRenderer(this);
        this.translateService = this.injector.get(OTranslateService);
        this.renderType = ODataTableCellRendererActionComponent.DEFAULT_RENDER_TYPE;
    }
    ODataTableCellRendererActionComponent.prototype.ngOnInit = function () {
        this.tableColumn.updateRendererType('action');
        if ((typeof (this.renderValue) === 'undefined') &&
            ODataTableCellRendererActionComponent.DEFAULT_RENDER_VALUES.hasOwnProperty(this.action)) {
            this.renderValue = ODataTableCellRendererActionComponent.DEFAULT_RENDER_VALUES[this.action];
        }
        if (this.renderType === 'icon' && this.tableColumn.width === undefined) {
            this.tableColumn.setWidth('2px');
        }
    };
    ODataTableCellRendererActionComponent.prototype.init = function (parameters) {
        if (typeof (parameters) !== 'undefined') {
            if (typeof (parameters.action) !== 'undefined') {
                this.action = parameters.action;
            }
            if (typeof (parameters.editionMode) !== 'undefined') {
                this.editionMode = parameters.editionMode;
            }
            if (typeof (parameters.renderType) !== 'undefined') {
                this.renderType = parameters.renderType;
            }
            if (typeof (parameters.renderValue) !== 'undefined') {
                this.renderValue = parameters.renderValue;
            }
            else if (ODataTableCellRendererActionComponent.DEFAULT_RENDER_VALUES.hasOwnProperty(this.action)) {
                this.renderValue = ODataTableCellRendererActionComponent.DEFAULT_RENDER_VALUES[this.action];
            }
        }
    };
    ODataTableCellRendererActionComponent.prototype.render = function (cellData, rowData) {
        var actionTitleKey = this.actionTitle;
        if (!this.actionTitle && (typeof (this.action) !== 'undefined')) {
            actionTitleKey = this.action.toUpperCase();
        }
        var actionTranslated = (typeof (actionTitleKey) !== 'undefined') ? this.translateService.get(actionTitleKey) : '';
        var result = '<div class="o-table-row-action" title="' + actionTranslated + '">';
        switch (this.renderType) {
            case 'string':
                result += this.translateService.get(this.renderValue);
                break;
            case 'icon':
                result += '<md-icon class="material-icons">' + this.renderValue + '</md-icon>';
                break;
            case 'image':
                result += '<img src="' + this.renderValue + '" />';
                break;
            case 'button':
                result += '<button type="button" md-raised-button>';
                result += '<span class="o-button-text">' + this.translateService.get(this.renderValue) + '</span>';
                result += '</button>';
                break;
        }
        result += '</div>';
        return result;
    };
    ODataTableCellRendererActionComponent.prototype.handleCreatedCell = function (cellElement, rowData) {
        var _this = this;
        cellElement.bind('click', function (e) {
            e.stopPropagation();
            _this.onClick.emit(rowData);
            if (typeof (_this.action) !== 'undefined') {
                switch (_this.action.toLowerCase()) {
                    case ODataTableCellRendererActionComponent.ACTION_DETAIL:
                        _this.tableColumn.viewDetail(rowData);
                        break;
                    case ODataTableCellRendererActionComponent.ACTION_DELETE:
                        _this.tableColumn.remove(rowData);
                        break;
                    case ODataTableCellRendererActionComponent.ACTION_EDIT:
                        if (_this.editionMode === 'inline') {
                            _this.handleInlineEditActionClick(cellElement, rowData);
                        }
                        else {
                            _this.tableColumn.editDetail(rowData);
                        }
                        break;
                }
            }
        });
    };
    ODataTableCellRendererActionComponent.prototype.handleInlineEditActionClick = function (cellElement, rowData) {
        var _this = this;
        cellElement.bind('click', function (e) {
            e.stopPropagation();
            _this.tableColumn.renderRowEditors(cellElement);
            cellElement.html(_this.renderEditActions());
            cellElement.find('.o-table-row-action-edit-cancel').bind('click', function (e) {
                e.stopPropagation();
                _this.tableColumn.renderRowRenderers(cellElement, rowData);
                cellElement.html(_this.render(undefined, undefined));
                _this.handleCreatedCell(cellElement, rowData);
            });
            cellElement.find('.o-table-row-action-edit-save').bind('click', function (e) {
                e.stopPropagation();
                var av = _this.tableColumn.getRowEditorsAttrValues(cellElement);
                if (typeof (av) !== 'undefined') {
                    for (var i in av) {
                        if (rowData.hasOwnProperty(i)) {
                            rowData[i] = av[i];
                        }
                    }
                    _this.tableColumn.updateRow(cellElement, av);
                }
                _this.tableColumn.renderRowRenderers(cellElement, rowData);
                cellElement.html(_this.render(undefined, undefined));
                _this.handleCreatedCell(cellElement, rowData);
            });
        });
    };
    ODataTableCellRendererActionComponent.prototype.renderEditActions = function () {
        var html = '<md-icon class="o-table-row-action-edit-cancel material-icons" title="' + this.translateService.get('CANCEL') + '">' +
            ODataTableCellRendererActionComponent.EDIT_CANCEL_ICON +
            '</md-icon>' +
            '<md-icon class="o-table-row-action-edit-save material-icons" title="' + this.translateService.get('SAVE') + '">' +
            ODataTableCellRendererActionComponent.EDIT_SAVE_ICON +
            '</md-icon>';
        return html;
    };
    ODataTableCellRendererActionComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_ACTION = DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_ACTION;
    ODataTableCellRendererActionComponent.DEFAULT_OUTPUTS_O_DATATABLE_CELL_RENDERER_ACTION = DEFAULT_OUTPUTS_O_DATATABLE_CELL_RENDERER_ACTION;
    ODataTableCellRendererActionComponent.ACTION_DETAIL = 'detail';
    ODataTableCellRendererActionComponent.ACTION_DELETE = 'delete';
    ODataTableCellRendererActionComponent.ACTION_EDIT = 'edit';
    ODataTableCellRendererActionComponent.DEFAULT_RENDER_TYPE = 'icon';
    ODataTableCellRendererActionComponent.DEFAULT_RENDER_VALUES = {
        'detail': 'search',
        'delete': 'delete',
        'edit': 'edit'
    };
    ODataTableCellRendererActionComponent.EDIT_SAVE_ICON = 'done';
    ODataTableCellRendererActionComponent.EDIT_CANCEL_ICON = 'clear';
    ODataTableCellRendererActionComponent.decorators = [
        { type: Component, args: [{
                    selector: 'o-datatable-cell-renderer-action',
                    template: '',
                    inputs: DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_ACTION.slice(),
                    outputs: DEFAULT_OUTPUTS_O_DATATABLE_CELL_RENDERER_ACTION.slice()
                },] },
    ];
    ODataTableCellRendererActionComponent.ctorParameters = function () { return [
        { type: ODataTableColumnComponent, decorators: [{ type: Inject, args: [forwardRef(function () { return ODataTableColumnComponent; }),] },] },
        { type: Injector, },
    ]; };
    return ODataTableCellRendererActionComponent;
}());
export { ODataTableCellRendererActionComponent };
//# sourceMappingURL=o-datatable-cell-renderer-action.component.js.map