import { Component, Inject, forwardRef, EventEmitter } from '@angular/core';
import { Util } from 'ontimize-web-ng2';
import { ODataTableColumnComponent } from '../o-datatable-column.component';
export var DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_IMAGE = [
    'imageType: image-type',
    'emptyImage: empty-image',
    'avatar'
];
export var DEFAULT_OUTPUTS_O_DATATABLE_CELL_RENDERER_IMAGE = [
    'onClick'
];
var ODataTableCellRendererImageComponent = (function () {
    function ODataTableCellRendererImageComponent(tableColumn) {
        this.tableColumn = tableColumn;
        this.onClick = new EventEmitter();
        tableColumn.registerRenderer(this);
    }
    ODataTableCellRendererImageComponent.prototype.ngOnInit = function () {
        this.avatar = Util.parseBoolean(this.avatar, false);
        this.tableColumn.updateRendererType('image');
    };
    ODataTableCellRendererImageComponent.prototype.init = function (parameters) {
        if (typeof (parameters) !== 'undefined') {
            if (typeof (parameters.imageType) !== 'undefined') {
                this.imageType = parameters.imageType;
            }
            if (typeof (parameters.avatar) !== 'undefined') {
                this.avatar = parameters.avatar;
            }
            if (typeof (parameters.emptyImage) !== 'undefined') {
                this.emptyImage = parameters.emptyImage;
            }
        }
    };
    ODataTableCellRendererImageComponent.prototype.render = function (cellData, rowData) {
        var template = '<div class="' + (this.avatar ? 'image-avatar' : 'image-plain') + '">';
        var imageSrc = '';
        switch (this.imageType) {
            case 'base64':
                imageSrc = cellData ? ('data:image/*;base64,' + ((typeof (cellData.bytes) !== 'undefined') ? cellData.bytes : cellData)) : this.emptyImage;
                break;
            case 'url':
                imageSrc = cellData ? cellData : this.emptyImage;
                break;
            default:
                imageSrc = this.emptyImage;
                break;
        }
        if (typeof (imageSrc) !== 'undefined') {
            template += '<img src="' + imageSrc + '" />';
        }
        template += '</div>';
        return template;
    };
    ODataTableCellRendererImageComponent.prototype.handleCreatedCell = function (cellElement, rowData) {
        var _this = this;
        cellElement.bind('click', function (e) {
            e.stopPropagation();
            _this.onClick.emit(rowData);
        });
    };
    ODataTableCellRendererImageComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_IMAGE = DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_IMAGE;
    ODataTableCellRendererImageComponent.DEFAULT_OUTPUTS_O_DATATABLE_CELL_RENDERER_IMAGE = DEFAULT_OUTPUTS_O_DATATABLE_CELL_RENDERER_IMAGE;
    ODataTableCellRendererImageComponent.decorators = [
        { type: Component, args: [{
                    selector: 'o-datatable-cell-renderer-image',
                    template: '',
                    inputs: DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_IMAGE.slice()
                },] },
    ];
    ODataTableCellRendererImageComponent.ctorParameters = function () { return [
        { type: ODataTableColumnComponent, decorators: [{ type: Inject, args: [forwardRef(function () { return ODataTableColumnComponent; }),] },] },
    ]; };
    return ODataTableCellRendererImageComponent;
}());
export { ODataTableCellRendererImageComponent };
//# sourceMappingURL=o-datatable-cell-renderer-image.component.js.map