import { Component, Inject, Injector, forwardRef } from '@angular/core';
import { ODataTableComponent } from './o-datatable.component';
import { ODataTableCellRendererStringComponent, ODataTableCellRendererBooleanComponent, ODataTableCellRendererIntegerComponent, ODataTableCellRendererRealComponent, ODataTableCellRendererCurrencyComponent, ODataTableCellRendererDateComponent, ODataTableCellRendererImageComponent, ODataTableCellRendererActionComponent } from './cell-renderer/cell-renderer';
import { ODataTableCellEditorStringComponent, ODataTableCellEditorBooleanComponent, ODataTableCellEditorIntegerComponent, ODataTableCellEditorRealComponent, ODataTableCellEditorDateComponent } from './cell-editor/cell-editor';
import { OTranslateService, MomentService, NumberService, CurrencyService, Util } from 'ontimize-web-ng2';
export var DEFAULT_INPUTS_O_DATATABLE_COLUMN = [
    'attr',
    'title',
    'orderable',
    'searchable',
    'type',
    'editable',
    'dateModelType: date-model-type',
    'dateModelFormat: date-model-format',
    'width',
    'class'
];
var ODataTableColumnComponent = (function () {
    function ODataTableColumnComponent(table, injector) {
        this.injector = injector;
        this.renderer = undefined;
        this.editor = undefined;
        this.table = table;
        this.translateService = this.injector.get(OTranslateService);
        this.momentService = this.injector.get(MomentService);
        this.numberService = this.injector.get(NumberService);
        this.currencyService = this.injector.get(CurrencyService);
    }
    ODataTableColumnComponent.prototype.ngOnInit = function () {
        this.editable = (typeof (this.editable) !== 'undefined') ?
            Util.parseBoolean(this.editable, false) :
            this.table.isColumnEditable(this.attr) || (this.editor !== undefined);
        this.orderable = Util.parseBoolean(this.orderable, true);
        this.searchable = Util.parseBoolean(this.searchable, true);
        this.grouping = Util.parseBoolean(this.grouping, true);
        this.translate = Util.parseBoolean(this.translate, false);
        if (typeof (this.dateModelType) === 'undefined') {
            this.dateModelType = ODataTableColumnComponent.DEFAULT_DATE_MODEL_TYPE;
            this.dateModelType = ODataTableCellEditorDateComponent.DEFAULT_DATE_MODEL_TYPE;
        }
        if (typeof (this.dateModelFormat) === 'undefined') {
            this.dateModelFormat = ODataTableColumnComponent.DEFAULT_DATE_MODEL_FORMAT;
            this.dateModelFormat = ODataTableCellEditorDateComponent.DEFAULT_DATE_MODEL_FORMAT;
        }
        if (typeof (this.decimalDigits) === 'undefined') {
            this.decimalDigits = this.numberService.decimalDigits;
        }
        if (typeof (this.currencySymbol) === 'undefined') {
            this.currencySymbol = this.currencyService.symbol;
        }
        if (typeof (this.currencySymbolPosition) === 'undefined') {
            this.currencySymbolPosition = this.currencyService.symbolPosition;
        }
        if (typeof (this.renderer) === 'undefined') {
            switch (this.type) {
                case 'boolean':
                    this.renderer = new ODataTableCellRendererBooleanComponent(this, this.injector);
                    this.renderer.init({
                        trueValueType: this.trueValueType,
                        trueValue: this.trueValue,
                        falseValueType: this.falseValueType,
                        falseValue: this.falseValue
                    });
                    if (this.editable && (typeof (this.editor) === 'undefined')) {
                        this.editor = new ODataTableCellEditorBooleanComponent(this);
                    }
                    break;
                case 'integer':
                    this.renderer = new ODataTableCellRendererIntegerComponent(this, this.injector);
                    this.renderer.init({
                        grouping: this.grouping,
                        thousandSeparator: this.thousandSeparator
                    });
                    if (this.editable && (typeof (this.editor) === 'undefined')) {
                        this.editor = new ODataTableCellEditorIntegerComponent(this);
                    }
                    break;
                case 'real':
                    this.renderer = new ODataTableCellRendererRealComponent(this, this.injector);
                    this.renderer.init({
                        grouping: this.grouping,
                        thousandSeparator: this.thousandSeparator,
                        decimalSeparator: this.decimalSeparator,
                        decimalDigits: this.decimalDigits
                    });
                    if (this.editable && (typeof (this.editor) === 'undefined')) {
                        this.editor = new ODataTableCellEditorRealComponent(this);
                    }
                    break;
                case 'currency':
                    this.renderer = new ODataTableCellRendererCurrencyComponent(this, this.injector);
                    this.renderer.init({
                        grouping: this.grouping,
                        thousandSeparator: this.thousandSeparator,
                        decimalSeparator: this.decimalSeparator,
                        decimalDigits: this.decimalDigits,
                        currencySymbol: this.currencySymbol,
                        currencySymbolPosition: this.currencySymbolPosition
                    });
                    if (this.editable && (typeof (this.editor) === 'undefined')) {
                        this.editor = new ODataTableCellEditorRealComponent(this);
                    }
                    break;
                case 'date':
                    this.renderer = new ODataTableCellRendererDateComponent(this, this.injector);
                    this.renderer.init({
                        format: this.format
                    });
                    if (this.editable && (typeof (this.editor) === 'undefined')) {
                        this.editor = new ODataTableCellEditorDateComponent(this, this.injector);
                        this.editor.init({
                            dateModelType: this.dateModelType,
                            dateModelFormat: this.dateModelFormat,
                            rendererFormat: this.format
                        });
                    }
                    break;
                case 'image':
                    this.renderer = new ODataTableCellRendererImageComponent(this);
                    this.renderer.init({
                        imageType: this.imageType,
                        avatar: this.avatar,
                        emptyImage: this.emptyImage
                    });
                    break;
                case 'action':
                    this.renderer = new ODataTableCellRendererActionComponent(this, this.injector);
                    this.renderer.init({
                        action: this.action,
                        renderType: this.renderType,
                        renderValue: this.renderValue
                    });
                    break;
                default:
                    this.renderer = new ODataTableCellRendererStringComponent(this, this.injector);
                    this.renderer.init({
                        translate: this.translate
                    });
                    if (this.editable && (typeof (this.editor) === 'undefined')) {
                        this.editor = new ODataTableCellEditorStringComponent(this);
                    }
                    break;
            }
        }
        if (this.attr === undefined) {
            var columnIndex = this.table.getColumsNumber();
            this.generatedAttr = 'o-table-column-' + columnIndex;
        }
        if (this.width && this.width.length && this.width.endsWith('px')) {
            var newWidth = (parseInt(this.width) - 24);
            if (newWidth <= 0) {
                newWidth = 1;
            }
            this.width = newWidth + 'px';
        }
        this.table.registerColumn(this);
    };
    ODataTableColumnComponent.prototype.setWidth = function (value) {
        this.width = value;
        this.table.setInitialColumnWidth(this);
    };
    ODataTableColumnComponent.prototype.getColumnName = function () {
        return this.attr || this.generatedAttr;
    };
    ODataTableColumnComponent.prototype.registerRenderer = function (renderer) {
        this.renderer = renderer;
    };
    ODataTableColumnComponent.prototype.updateRendererType = function (rendererType) {
        this.table.updateDataTableOptions(this.attr, rendererType);
    };
    ODataTableColumnComponent.prototype.registerEditor = function (editor) {
        this.editor = editor;
    };
    ODataTableColumnComponent.prototype.render = function (cellData, rowData) {
        this.cellData = cellData;
        return this.renderer.render(cellData, rowData);
    };
    ODataTableColumnComponent.prototype.handleCreatedCell = function (cellElement, rowData) {
        this.cellElement = cellElement;
        this.renderer.handleCreatedCell(cellElement, rowData);
    };
    ODataTableColumnComponent.prototype.updateCell = function (cellElement, value, sqltypes) {
        this.table.updateCell(cellElement, value, sqltypes);
    };
    ODataTableColumnComponent.prototype.updateRow = function (cellElement, av) {
        this.table.updateRow(cellElement, av);
    };
    ODataTableColumnComponent.prototype.viewDetail = function (item) {
        this.table.viewDetail(item);
    };
    ODataTableColumnComponent.prototype.editDetail = function (item) {
        this.table.editDetail(item);
    };
    ODataTableColumnComponent.prototype.remove = function (item) {
        this.table.select(item);
        this.table.remove(true);
    };
    ODataTableColumnComponent.prototype.renderRowRenderers = function (cellElement, rowData) {
        this.table.renderRowRenderers(cellElement, rowData);
    };
    ODataTableColumnComponent.prototype.renderRowEditors = function (cellElement) {
        this.table.renderRowEditors(cellElement);
    };
    ODataTableColumnComponent.prototype.getRowEditorsAttrValues = function (cellElement) {
        return this.table.getRowEditorsAttrValues(cellElement);
    };
    ODataTableColumnComponent.prototype.getRowData = function () {
        if (!this.table || !this.cellElement) {
            return undefined;
        }
        return this.table.getRowDataFromColumn(this);
    };
    ODataTableColumnComponent.DEFAULT_INPUTS_O_DATATABLE_COLUMN = DEFAULT_INPUTS_O_DATATABLE_COLUMN;
    ODataTableColumnComponent.DEFAULT_DATE_MODEL_TYPE = 'timestamp';
    ODataTableColumnComponent.DEFAULT_DATE_MODEL_FORMAT = 'YYYY-MM-DD HH:mm:ss';
    ODataTableColumnComponent.decorators = [
        { type: Component, args: [{
                    selector: 'o-datatable-column',
                    template: "\n    <!-- empty -->\n  ",
                    styles: ["\n\n  "],
                    inputs: DEFAULT_INPUTS_O_DATATABLE_COLUMN.concat(ODataTableCellRendererBooleanComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_BOOLEAN, ODataTableCellRendererCurrencyComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_CURRENCY, ODataTableCellRendererDateComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_DATE, ODataTableCellRendererImageComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_IMAGE, ODataTableCellRendererActionComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_ACTION, ODataTableCellEditorDateComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_EDITOR_DATE, ODataTableCellRendererStringComponent.DEFAULT_INPUTS_O_DATATABLE_CELL_RENDERER_STRING)
                },] },
    ];
    ODataTableColumnComponent.ctorParameters = function () { return [
        { type: ODataTableComponent, decorators: [{ type: Inject, args: [forwardRef(function () { return ODataTableComponent; }),] },] },
        { type: Injector, },
    ]; };
    return ODataTableColumnComponent;
}());
export { ODataTableColumnComponent };
//# sourceMappingURL=o-datatable-column.component.js.map